/* _dict.cc 14/12/1998 19.23.12 */
/* filter.cc 07/08/2000 00.52.42 */
PRIVATE void CONFDB_SUSE::reset_modified (void);
PUBLIC CONFDB_SUSE::CONFDB_SUSE (CONFDB *_orig);
PUBLIC CONFDB_SUSE::~CONFDB_SUSE (void);
PUBLIC void CONFDB_SUSE::setcursys (const char *_subsys);
PUBLIC int CONFDB_SUSE::save (PRIVILEGE *priv);
PRIVATE const char *CONFDB_SUSE::getvalfromrh (SUSELK *rh);
PRIVATE void CONFDB_SUSE::updaterh (SUSELK *rh, const char *val);
PUBLIC const char *CONFDB_SUSE::getval (const char *prefix,
	 const char *key,
	 const char *defval);
PUBLIC int CONFDB_SUSE::getall (const char *prefix,
	 const char *key,
	 SSTRINGS&lst,
	 bool copy);
PUBLIC void CONFDB_SUSE::removeall (const char *prefix,
	 const char *key);
PUBLIC void CONFDB_SUSE::add (const char *prefix,
	 const char *key,
	 const char *val);
PUBLIC int CONFDB_SUSE::archive (SSTREAM&ss, const char *_sys);
PUBLIC int CONFDB_SUSE::extract (SSTREAM&ss, const char *_sys);
/* ipalias.cc 14/12/1998 19.23.12 */
/* routes.cc 07/08/2000 00.53.16 */
/* suse.cc 28/08/2000 18.14.54 */
PUBLIC MODULE_suse::MODULE_suse (void);
PUBLIC int MODULE_suse::dohtml (const char *key);
PUBLIC int MODULE_suse::execmain (int argc, char *argv[], bool);
/* pam.cc 21/08/2000 22.36.34 */
/* reduser.cc 15/03/2000 11.29.28 */
